plot3dstatic <- function(x, plot.type = "jointplot", plot.dim = c(1,2,3), col.r, col.c, arrows = TRUE, 
                                 main, xlab, ylab, zlab, xlim, ylim, zlim, ...)UseMethod("plot3dstatic")
